@@ -21,7 +21,7 @@ def exists_base_object(table_name, schem_aname='public'):
     with connection.cursor() as cursor:
         cursor.execute(sql_text, [table_name, schem_aname])
         rows = cursor.fetchone()
-        if rows == None:
+        if rows is None:
             return False
         else:
             return len(rows) > 0
@@ -32,7 +32,7 @@ def create_tmp_mat_view(sql_str, params=[], indexes=[], mat_view_name=None, chec
         return mat_view_name
 
     key = f'create_tmp_mat_view_{mat_view_name}'
-    if mat_view_name != None:
+    if mat_view_name is not None:
         settings.LOCKS.acquire(key)
     else:
         mat_view_name = f'tmp_{uuid4()}'
@@ -46,19 +46,19 @@ def create_tmp_mat_view(sql_str, params=[], indexes=[], mat_view_name=None, chec
             logger.debug(f'Creating: {mat_view_name}')
             cursor.execute(sql_txt, params)
             logger.debug(f'Created: {mat_view_name}')
-        if mat_view_name != None:
+        if mat_view_name is not None:
             settings.LOCKS.release(key)
         return mat_view_name
     except Exception as ex:
         exc_info = sys.exc_info()
         logger.error(msg=ex, exc_info=exc_info)
-        if mat_view_name != None:
+        if mat_view_name is not None:
             settings.LOCKS.release(key)
         return None
 
 
 def create_view(sql_str, params=[], view_name=None) -> None:
-    if view_name == None:
+    if view_name is None:
         raise Exception(f'View must have name')
 
     if exists_base_object(view_name):
@@ -111,7 +111,7 @@ def create_insert_update_delete_function_of_table(
                 return f'''{f'{prefix}.' if prefix else ''}"{param_item[0]}"=f{param_item[0]}'''
 
             def func_where_clause_str1(param_item, prefix1=None, prefix2=None):
-                prefix2 = '' if prefix2 == None else f'{prefix2}.'
+                prefix2 = '' if prefix2 is None else f'{prefix2}.'
                 return f'''{f'{prefix1}.' if prefix1 else ''}"{param_item[0]}"={prefix2}"{param_item[0]}"'''
 
             func_params1 = ','.join(f'f{func_param_str(a)}' for a in func_params)
@@ -192,14 +192,14 @@ def create_insert_update_delete_function_of_table(
 
 
 def create_table(fields_str=None, sql_str=None, temporary='', on_commit=None, params=[], indexes=[], unique_indexes=[], primary_key=None, table_name=None, drop=True) -> None:
-    if table_name == None:
+    if table_name is None:
         raise Exception(f'Table must have name')
 
     key = f'create_tmp_table{table_name}'
     settings.LOCKS.acquire(key)
 
     pk_str = ''
-    if primary_key != None:
+    if primary_key is not None:
         if not isinstance(primary_key, list):
             primary_key = [primary_key]
 
@@ -222,10 +222,10 @@ def create_table(fields_str=None, sql_str=None, temporary='', on_commit=None, pa
         sql_txt = f'''DROP TABLE IF EXISTS {table_name} CASCADE;'''
 
     on_commit_str = f'ON COMMIT {on_commit}'
-    if on_commit == None:
+    if on_commit is None:
         on_commit_str = ''
 
-    if sql_str == None:
+    if sql_str is None:
         sql_txt += f'''CREATE {temporary} TABLE {table_name} ({fields_str}) {on_commit_str};'''
     else:
         sql_txt += f'''CREATE {temporary} TABLE {table_name} as ({sql_str}); {on_commit_str};'''
@@ -299,7 +299,7 @@ def refresh_mat_view(mat_view_name, username=None):
                 cursor.execute(sql_txt)
             settings.LOCKS.release(key)
 
-            if username != None:
+            if username is not None:
                 WebSocket.send_info_message(
                     host=settings.WS_HOST,
                     port=settings.WS_PORT,
