@@ -196,6 +196,12 @@ class DSRequest(RPCRequest):
         if isinstance(data, dict):
             setAttr(self.json, 'data', data)
 
+    def set_sort_by(self, sort_by):
+        if not isinstance(sort_by, list):
+            sort_by = [sort_by]
+
+        setAttr(self.json, 'sortBy', sort_by)
+
     def set_criteria(self, criteria, excluded_keys=['grid']):
         data = self.get_all_data(excluded_keys=excluded_keys)
         if isinstance(data, dict):
