@@ -61,7 +61,7 @@ class Progress:
         self.id = id
         self.enable_ws_progress = IsBitOff(self.props, 1)
 
-        if self.enable_ws_progress is True:
+        if self.enable_ws_progress == True:
             if isinstance(user, int):
                 self.user = User.objects.get(id=user)
             elif isinstance(user, User):
@@ -71,7 +71,7 @@ class Progress:
 
         self.qty = qty
 
-        if self.enable_ws_progress is False:
+        if self.enable_ws_progress == False:
             self.pbar = tqdm(total=qty)
         else:
             # if self.qty > 0:
@@ -122,7 +122,7 @@ class Progress:
         from isc_common.models.deleted_progresses import Deleted_progresses
 
         res = 0
-        if self.enable_ws_progress is True:
+        if self.enable_ws_progress == True:
             if self.progress is not None:
                 self.progress.setCntDone(self.cnt, self.id)
                 self.cnt += 1
