@@ -86,7 +86,7 @@ class MessagesManager(CommonTreeGridManager):
             'to_whom__short_name': record.to_whom.get_short_name,
             'to_whom__username': record.to_whom.username,
             'to_whom_id': record.to_whom.id,
-            'user__color': record.user.color if record.user.color != None and record.user.color != 'undefined' else 'black',
+            'user__color': record.user.color if record.user.color is not None and record.user.color != 'undefined' else 'black',
             'user__full_name': record.user.get_full_name,
             'user__short_name': record.user.get_short_name,
             'user_id': record.user.id if record.user else None,
